"
 COPYRIGHT (c) 1989 by Claus Gittinger
	      All Rights Reserved

 This software is furnished under a license and may be used
 only in accordance with the terms of that license and with the
 inclusion of the above copyright notice.   This software may not
 be provided or otherwise made available to, or used by, any
 other person.  No title to or ownership of the software is
 hereby transferred.
"
"{ Package: 'stx:libwidg' }"

"{ NameSpace: Smalltalk }"

DialogBox subclass:#InfoBox
	instanceVariableNames:'formAndLabelPanel formLabel textLabel'
	classVariableNames:'InfoBitmap'
	poolDictionaries:''
	category:'Views-DialogBoxes'
!

!InfoBox class methodsFor:'documentation'!

copyright
"
 COPYRIGHT (c) 1989 by Claus Gittinger
	      All Rights Reserved

 This software is furnished under a license and may be used
 only in accordance with the terms of that license and with the
 inclusion of the above copyright notice.   This software may not
 be provided or otherwise made available to, or used by, any
 other person.  No title to or ownership of the software is
 hereby transferred.
"


!

documentation
"
   Historic note:
        originally, ST/X had separate classes for the various entry methods;
        there were YesNoBox, EnterBox, InfoBox and so on.
        In the meantime, the DialogBox class (and therefore its alias: Dialog)
        is going to duplicate most functionality found in these classes.

        In the future, those existing subclasses' functionality is going to
        be moved fully into Dialog, and the subclasses will be replaced by dummy
        delegators. (They will be kept for backward compatibility, though).



    this class implements a pop-up box to show an information message.
    It has a single ok-Button, which closes the box.
    Also entering return has (by default) the same effect as pressing
    the ok-button.
    InfoBox is a superclass of some other boxes - see WarningBox, YesNoBox etc.
    most of them simply redefine the icon shown in the upper left or
    add buttons.

    [instance variables:]

        formLabel        <Label>        shows a bitmap (warning, question-mark)

        textLabel        <Label>        shows the boxes text


    [author:]
        Claus Gittinger
"
!

examples
"
    Notice, the preferred use is via the DialogBox class messages,
    such as
                                                                        [exBegin]
        Dialog information:'Time to go home'
                                                                        [exEnd]
    these (DialogBox) mesages are compatible with VW and should therefore
    be used for portability.

    Direct use of InfoBox is only required for highly specialized boxes.



    InfoBoxes are created with:

        aBox := InfoBox title:'some title'.

    and shown with:

        aBox showAtPointer
    or
        aBox open

    The default box shows 'yes' in its button; this can be changed with:

        aBox okText:'some string'.

    the boxes bitmap-image can be changed with:

        aBox image:aForm


    Since this type of information is pretty common, a convenient information
    method has been added to Object.
    Thus, you can use:
                                                                        [exBegin]
        self information:'hello world'
                                                                        [exEnd]

    everwhere in your program.
    for ST-80 compatibility, you can also use:
                                                                        [exBegin]
        Dialog information:'hello world'
                                                                        [exEnd]



    standard box:
                                                                        [exBegin]
        |box|

        box := InfoBox title:'hello world '.
        box open
                                                                        [exEnd]


    changing the buttons label:
                                                                        [exBegin]
        |box|

        box := InfoBox title:'hello world '.
        box okText:'wow'.
        box open
                                                                        [exEnd]


    changing the icon:

                                                                        [exBegin]
        |box|

        box := InfoBox title:'hello world '.
        box image:(Image fromFile:'libtool/bitmaps/SBrowser.xbm' inPackage:'stx:libtool').
        box okText:'wow'.
        box open
                                                                        [exEnd]

    or even:
                                                                        [exBegin]
        |box|

        box := InfoBox title:'hello garfield '.
        box image:((Image fromFile:'garfield.gif' inPackage:'stx:goodies/bitmaps/gifImages') magnifiedTo:200@100).
        box okText:'wow'.
        box open
                                                                        [exEnd]


    If you plan to use boxes as in the last example, you may want to
    keep the box around for reuse (since the image magnification takes some time).
                                                                        [exBegin]
        |box|

        box := InfoBox title:'hello garfield '.
        box image:((Image fromFile:'garfield.gif' inPackage:'stx:goodies/bitmaps/gifImages') magnifiedTo:200@100).
        box okText:'wow'.
        box open.

        box title:'hello again'.
        box open
                                                                        [exEnd]

"
! !

!InfoBox class methodsFor:'instance creation'!

title:titleString
    "create a new infoBox with title, aTitleString"

    ^ (self new) title:titleString

    "
     (InfoBox title:'hello') open
    "

    "Modified: / 22-12-2010 / 19:30:50 / cg"
!

title:titleString label:labelString
    "create a new infoBox with label, labelString"

    ^ (self new) title:titleString label:labelString

    "
     (InfoBox title:'hello' label:'Attention' ) open
    "

    "Created: / 22-12-2010 / 19:31:03 / cg"
! !

!InfoBox class methodsFor:'defaults'!

defaultLabel
    "return the boxes default window title."

    ^ 'Info'

    "Created: 23.4.1996 / 17:12:33 / cg"
!

iconBitmap
    "return the bitmap shown as icon in my instances.
     This is the default image; you can overwrite this in a concrete
     instance with the #image: message"

    <resource: #style (#'infoBox.icon' #'infoBox.iconFile')>

    InfoBitmap isNil ifTrue:[
        InfoBitmap := self iconBitmapFromStyle:'infoBox.icon' orStyleFile:'infoBox.iconFile' orFilename:'bitmaps/Information.xbm'.
    ].
    ^ InfoBitmap

    "
     InfoBitmap := self iconWithAlpha
    "

    "Modified: / 26.10.1997 / 17:02:51 / cg"
!

iconBitmapFromStyle:styleName orStyleFile:styleFile orFilename:fileName
    "return the bitmap shown as icon in my instances.
     This is the default image; you can overwrite this in a concrete
     instance with the #image: message"

    |img imgFileName|

    img := self styleSheet at:styleName.
    img isNil ifTrue:[
        imgFileName := StyleSheet at:styleFile default:fileName.
        img := Smalltalk imageFromFileNamed:imgFileName forClass:self.
    ].
    img notNil ifTrue:[
        img := img onDevice:Display
    ].
    ^ img

    "Modified: / 26.10.1997 / 17:02:51 / cg"
! !

!InfoBox class methodsFor:'image specs'!

iconWithAlpha
    "This resource specification was automatically generated
     by the ImageEditor of ST/X."

    "Do not manually edit this!! If it is corrupted,
     the ImageEditor may not be able to read the specification."

    "
     self iconWithAlpha inspect
     ImageEditor openOnClass:self andSelector:#iconWithAlpha
     Icon flushCachedIcons
    "

    <resource: #image>

    ^Icon
        constantNamed:'WarningBox class iconWithAlpha'
        ifAbsentPut:[(Depth32Image width:32 height:32 photometric:(#rgba)) bitsPerSample:(#[8 8 8 8]); bits:(ByteArray fromPackedString:'
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@M?_8O?_8NC?8NC ?>C 8O? 8NC?8NC ?>C 8O? 8NC?8NC ?=? 8O?@0LC?7=?@?0@@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@0LC@?<C_7???????????????????????
????????????????????????????????????????????????(K>??=?_0O<@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@8NC ?>C 8O??????????????????????????????????????/<C@?:B /????????????????????????????????????????????:B?0O<@@@@@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@M?_8O? 8NC???? ?????????????????????????????????3=__?<@@C??@@@??0@_
W????????????????????????????????????????????;?@7?>?0K??@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@C_7>C?8NC ?>C 8O??????
???????????????????????????@7=??@@A@?0@_ O<@G8C?@@A ?7>@/?????????????????????????????????? 8O???????<C_8O> /;??@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@@7=? ?>C 8O? 8NC??????????????????????????????????????>C ??<@@FC?@BB_?4B@7?<@HJC?'':C_????????????
8O???????????????????>C???? 8O??8O???:C@7?>?/;??@@@@@@@@@@@@@@@@@@@@@M?_7??_7=??8NC ?>C?????????????????????????????????
?????????????8B_0O<_PJC?W8C ?6B@0O???????????>C???? ????8O???>C??????????????>C????_8O??8O???7>_(O?@0K>@@@@@@@@@@@@@@@@@
0M?_?=?_8O? 8O????????????????????????????????????????????????????????????????????????????? ????8O???>C???? ????8O???>C?
?????????????=? ???_8O??0M? ?7=?''??_7<B@@@@@@M?_7??_7=??7>C ?>C?????????8O???>C???? ????8O???>C?????????????????????????
??????????? ????8O???>C???? ????8O???>C???? ????8NC??=??????????8O???=? ??? ????W7>_?9> (H@@@@@@/<C_?=?_7??_8NC?????????
??? ????8O???>C???? ????8O???>C???=  JC?G3= ?2A@ O<?PHC?G3= ?0@_PO>@'';???????>C???? ????7>C??=? ???_8O??7>C??>C???? ????
7>C??=? ??> 0NC?XFB@?=?_0HB?0LC?0M?_?=? ??? ????8O???>C???? ????8O???>C???? ????8O???8B_0O<@HHC?@@A??0@_ O<@HHC?@@A ?7>_
0O??????7????=? ???_8O??7>C??=? ???_8O??7>C??>C????_8O??0M? ?;?_8O<?PFC?(K>? K?@0O?@0M??7>C??>C???? ????8O???>C???? ????
8NC??>C???? ??????????????<_PI??@BB_?0@?''?<@G8C?_9?@???????_8O??7>C??=? ???_8O??7>C??=? ???_8O??7????<C ??>?7>C?/=? ?1<?
W?>_''9>@/<C@?;?@7??_8O??8O???>C???? ????7>C??=? ???_8O??7>C??=? ??? ?????????4A (O<@G8C?@C>_?0@_ O=?''<C?8O???=? ???_8O??
7>C??=? ???_8O??7>C??=? ???_8O??0NC??;?@8O>?7>C?G2A_?8B_''8B?0LC?/<C_?=? ??? ????7????=? ???_8O??7>C??=? ???_8O??7>C??=??
??? ????PFB_?0@_ O<@O9??@A>@?7>_0O? ????7>C??<C ???_8O??7>C??<C ???@8O??0NC??=? ???@8O??/<C ?;?@8O<_HE?? I>_ JB?0O>?0M??
0M? ?=?????_8O??7>C??=? ???_8O??7>C??=? ???_8O??7>C??>C???=@XI??@A>@?0@?''?<@G8C?_9?@?>C????_8O??0NC??<C ???@8O??0NC??<C 
???@8O??0NC??<C_??>?0NC?(LC ?1< W?>@''9>@(K?@?;>?0O>?7>C?7>C??=? ???_8O??7>C??=? ???_8O??7>C??=? ???_8O??8O???4A ''?<@G8C?
@C>_?0@_ O=?''<C?8O???<C ???@8O??0NC??<C ???@8O??0NC??<C ???@8O??/<C ?;?@7?>_/=??G2A_?8B_''8B?/<C?(K?@?;?@7??@7???7>C??=? 
???@8O??7>C??<C ???@8O??0NC??=? ???_????PFB_?0@_ O<@O9??@A>@?7>_0O?_????0NC??<C ???@8O??0NC??<C ???@8O??0NC??;?_??> 0NC?
(LC_?5= ''?<_HE??''9>  M?_0HB 0M??(K?@?;?@7??@8O??7>C??<C ???@8O??0NC??<C ???@8O??0NC??=????<?XI??@A>@?0@?''?<@G8C?_9?@?=??
???@8O??0NC??<C ???@8O??0NC??<C ??>?7???(LC ?:B?7?>_/=??HC= ?3=@XO>?/;>@@@@@@I> /?> /<C?(K?@?;?@8O?@8O??0NC??<C ???@8O??
0NC??<C ???@8O??7????4A ''?<@G8C?@BB_?0@__?=  LC?8O???<C ???@8O??/=???;?_??>?8O??/=???:C@8O>_/=??'';?_?5=?(O<@G4C?XG>@?=?_
0H@@@@@@7=?@ HB /?>_/<C?(K?@?;?@8O?@7???0NC??<C ???@8O??0NC??<C ??>?7???G3>@?0@ ''?<@O:C?@C>_?1=@ O>?7???0NC??;?_??>?8O??
/=???;?_??> 0NC?'';?_?9>?0O=?''<C?@BA_?2@?XO>_(JB@7=?@@@@@@@@@@@@@(K>??8B 0O>_(LC?'';?@?:C@8O>?7???0NC??<C ???_????_9?@?0@@
XO<@HI??G5>??2A_0O< W<C?G4B??0@? O>@(M??0NC??;?_??> 7???(LC ?9>?7?>_/<C?_:C@?2@?XO<_HE??_7>@ M?_0H@@@@@@@@@@@@@@@@@@@@@@
'':B??7>_/?>_/<C?'';?@?9>?7?> 0NC?/=???;? ??>?7???''<C??;?_??> 7???(LC??:C@??>?8O??(M???:C@??>?7???(LC ?9>?7?>_/<C?'';?@?6B_
/?< PG??G2A@?5= _8B?/;>@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@''9> ?6B@(O>@(LC?'':C@?9> 0O>_/=??'';?_?:C@8O>?7???/=???;?_??>?8O??
0NC??;? ??>?7???''<C ?9>?7?>@(LC? JC@?8B 0O=__:C?G2A_?1< PO=_XG??/;>? @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@(JB ?5= 
 O=  K?? JB??8B 0O>@(LC? JC@?8B 0O>@(LC?'';?_?9?@8O> 7???(LC??9>?7?>_(LC? JC@?8B 0O=  K??HDA??0@ PO< O5??XG>@ K>?/8@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@0LB? G>@''8A@XHC?O5>@?5=?(O=?'';??_9>??7>_/?>@(LC? JC@?9?@8O>_0NC? JC_?6B_
/?<?XHC?HDA??0@_PO< O5??W5=? I>_(HC@0LB@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@7=?@ K>?/8A? I>@
W6A??4A__?< O6C?O4A??7>_/?>@(LC?''<C ?:C@??>@(LC?G3= ?1< PO<?PFC?W6A??8B_''8C@0K>@8M?_@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@M?_0HC_7<B@7=?@ K>?/8A@PFC?O5=??8B?7?>_/>C?(M???7> 7?< O5??XG>@?:B?/8C@0LB@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@LC@
0H@?PFC?XI>??9>?8O> 0O??_:C_?2@?XO>_(JB@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@K>?/8@ O6C?W8B??:C@??= (M??HC=_?9>_(H@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@K?@/8A@W7??
_:C_?7> 7?<_O6C?''9>  @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@M?_0HA _8C?O6B_?2A@XO>_'':B@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@B (JB@ HB_ K>?
/0@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@a'); yourself]
! !

!InfoBox class methodsFor:'styles'!

updateStyleCache
    "extract values from the styleSheet and cache them in class variables.
     Here, the cached infoBitmap is simply flushed."

    InfoBitmap := nil

    "Modified: 1.4.1997 / 14:44:50 / cg"
! !

!InfoBox methodsFor:'accessing'!

form:aFormOrImage
    "historical leftover - define a form to be displayed left of the title"

    <resource:#obsolete>

    self image:aFormOrImage
!

formLabel
    "return the formLabel = can be used to change its appearance"

    ^ formLabel
!

image:aForm
    "define a form to be displayed left of the title
     - usually left as defaulted:
        an exclamation-mark here, warn-sign in warningBox,
        others in other subclasses."

    formLabel label:aForm.
    formLabel forceResize.
    formAndLabelPanel forceResize.
    verticalPanel forceResize.
    shown ifTrue:[self resize]
!

label
    ^ textLabel label

    "Created: / 26-08-2018 / 17:12:50 / Claus Gittinger"
!

textLabel
    "return the textLabel = can be used to change its appearance"

    ^ textLabel
!

title
    "return the boxes label string"
    "sigh: the old name for the windowTitle was label here,
     and the contents was called title.
     Squeak expects label to access the title"

    ^ self label

    "Created: / 22-12-2010 / 19:27:43 / cg"
    "Modified (comment): / 26-08-2018 / 18:11:29 / Claus Gittinger"
!

title:aString
    "return the boxes label string"
    "sigh: the old name for the windowTitle was label here,
     and the contents was called title.
     Squeak expects label to access the title"

    aString ~= textLabel label ifTrue:[
        textLabel label:aString.
        textLabel forceResize.
        formAndLabelPanel forceResize.
        verticalPanel forceResize.
        shown ifTrue:[self resize]
    ]

    "Created: / 26-08-2018 / 18:21:08 / Claus Gittinger"
!

title:labelString label:windowTitleString
    "set the boxes label string"
    "sigh: the old name for the windowTitle was label here,
     and the contents was called title.
     Squeak expects label to access the title"

    self windowTitle:windowTitleString.
    self title:labelString.

    "Modified: / 26-08-2018 / 18:25:47 / Claus Gittinger"
!

windowTitle
    ^ super label

    "Created: / 26-08-2018 / 17:03:56 / Claus Gittinger"
!

windowTitle:windowTitleString
    "set the boxes window title string"

    super label:windowTitleString.

    "Created: / 26-08-2018 / 17:01:23 / Claus Gittinger"
! !

!InfoBox methodsFor:'initialization'!

initFormBitmap
    "setup the bitmap shown in the upper left -
     extracted into a separate method for easier redefinition
     in subclasses"

    formLabel label:(self class iconBitmap)
!

initFormLabel
    "setup the icon shown in the infoBox.
     Can be redefined in subclasses."

    |mm|

    mm := ViewSpacing.

    formLabel := Label in:formAndLabelPanel.
    formLabel name: 'formLabel'.
    formLabel borderWidth:0.
"/    formLabel origin:(mm @ mm).

    "Created: / 16-11-1995 / 18:32:32 / cg"
    "Modified: / 22-04-1996 / 18:15:37 / cg"
    "Modified (format): / 28-02-2012 / 18:20:23 / cg"
!

initialize
    |mm sep|

    <modifier: #super> "must be called if redefined"

    super initialize.
    self addOkButton.

"/    label := 'Info'.

"/    mm := ViewSpacing.

    formAndLabelPanel := HorizontalPanelView in:self verticalPanel.

    self initFormLabel.
    self initFormBitmap.

    formLabel width > 500 ifTrue:[
        textLabel := Label label:'Information' in:verticalPanel.
    ] ifFalse:[
        textLabel := Label label:'Information' in:formAndLabelPanel.
    ].
    textLabel name: 'textLabel'.
    textLabel borderWidth:0.
    "/ textLabel origin:[(mm + formLabel widthIncludingBorder + mm) @ mm].

"/    yPosition := textLabel corner y.
"/    formLabel notNil ifTrue:[yPosition := yPosition max:(formLabel corner y)].
"/    yPosition := yPosition + ViewSpacing.

    (styleSheet at:'infoBoxSeparator' default:false) ifTrue:[
        sep := Separator in:self verticalPanel.
"/        sep origin:[0.0 @ ((formLabel bottom max:textLabel bottom) + mm)].
        sep width:1.0. "/ extent:(1.0 @ sep preferredHeight).
"/        yPosition := yPosition max:(sep corner y).
"/        yPosition := yPosition + ViewSpacing.
    ].

    "
     |b|

     b := InfoBox new.
     b title:'hello'.
     b open
    "

    "Modified: / 08-02-2017 / 00:26:21 / cg"
! !

!InfoBox methodsFor:'queries'!

beepWhenOpening
    ^ UserPreferences current beepForInfoDialog

    "
     Dialog information:'hello'
     Dialog warn:'hello'
     Dialog error:'hello'
    "
! !

!InfoBox class methodsFor:'documentation'!

version
    ^ '$Header$'
!

version_CVS
    ^ '$Header$'
! !

